==> ckmame-2.1.tar.xz: ckmame-2.1/src/Rom.h <==
#ifndef HAD_ROM_H
#define HAD_ROM_H


/*
  Rom.h -- information about one ROM
  Copyright (C) 1999-2021 Dieter Baron and Thomas Klausner

  This file is part of ckmame, a program to check rom sets for MAME.
  The authors can be contacted at <ckmame@nih.at>

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in
     the documentation and/or other materials provided with the
     distribution.
  3. The name of the author may not be used to endorse or promote
     products derived from this software without specific prior
     written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY
  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
  GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
  IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
  IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "FileData.h"

class Rom : public FileData {
public:
    enum Status {
        OK,
        BAD_DUMP,
        NO_DUMP
    };
    
    Rom() : FileData(), status(OK), where(FILE_INGAME) { }
    
    std::string merge;
    Status status;
    where_t where;

    const std::string &merged_name() const { return merge.empty() ? name : merge; }
    bool compare_merged(const FileData &other) const;
    bool compare_merged(const Rom &other) const;
    std::string filename(filetype_t filetype) const;
    bool is_mergable(const Rom &other) const;
    
    std::string status_name(bool verbose = false) const { return status_name(status); }
    static std::string status_name(Status status, bool verbose = false);
};

#endif // HAD_ROM_H

==> ckmame-3.0.tar.xz: ckmame-3.0/src/Rom.h <==
#ifndef HAD_ROM_H
#define HAD_ROM_H

/*
  Rom.h -- information about one ROM
  Copyright (C) 1999-2021 Dieter Baron and Thomas Klausner

  This file is part of ckmame, a program to check rom sets for MAME.
  The authors can be contacted at <ckmame@nih.at>

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in
     the documentation and/or other materials provided with the
     distribution.
  3. The name of the author may not be used to endorse or promote
     products derived from this software without specific prior
     written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY
  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
  GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
  IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
  IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "FileData.h"

class Rom : public FileData {
public:
    enum Status {
        OK,
        BAD_DUMP,
        NO_DUMP
    };
    
    Rom() : FileData(), status(OK), where(FILE_INGAME) { }
    
    std::string merge;
    Status status;
    where_t where;
    bool mia{false};

    const std::string &merged_name() const { return merge.empty() ? name : merge; }
    bool compare_merged(const FileData &other) const;
    bool compare_merged(const Rom &other) const;
    std::string filename(filetype_t filetype) const;
    bool is_mergable(const Rom &other) const;
    
    std::string status_name(bool verbose = false) const { return status_name(status, verbose); }
    static std::string status_name(Status status, bool verbose = false);
};

#endif // HAD_ROM_H
